// PS2 gamepad vibration feedback test
//
// Arnoud van Delden - December 2020
//
// Libs:
//   PS2X_lib from www.billporter.info
//      Try out all the buttons, X will vibrate the controller, faster as you press harder. Holding L1 or R1 
//      will print out the analog stick values. Go to www.billporter.info for updates and to report bugs.
//   Adafruit AdaFruit MotorShield

#include <Wire.h>
#include <PS2X_lib.h>
#include <Servo.h>
#include <Adafruit_MotorShield.h>

//#define DEBUG

Adafruit_MotorShield MShield = Adafruit_MotorShield(0x60);
PS2X ps2x; // PS2 gamepad Controller Class
int error = 0; 
byte controller_type = 0;

int speedloop = 0;
byte motor2speed = 0;

void setup() {
  Serial.begin(115200); // Start serial monitor  
  MShield.begin();       // Motor Shield init...
  Wire.setClock(400000); // Set I²C-Frequency to 400 kHz...

  // Setup pins and settings: config_gamepad(clock, command, attention, data, Pressures?, Rumble?)
  error = ps2x.config_gamepad(13, 11, 10, 12, true, true);     
  if (error == 0) {
    Serial.println("Found Controller, configured successful");
    controller_type = ps2x.readType();
    if (controller_type==1) {
      Serial.println("DualShock Controller Found");
    } else {
      Serial.println("Unknown Controller type");
    }
  } else {
    Serial.println("No controller found, check wiring");
  }
  delay(1000);
}

void loop() {
   // Just loop some ruble/vibration-feedback examples...

   // Only small motor ON for 2 seconds...
   ps2x.read_gamepad(true, 0);
   delay(2000);

   // All motors OFF for 2 seconds...
   ps2x.read_gamepad(false, 0);
   delay(1000);

   // Speedsteps Big motor steps...
   // PS2X_lib code says: "noting below 40 will make it spin"
   // Furthermore, it seems go through 2 cycles when you step all the way to 255. Possibly a 7 bit byte?
   //
   motor2speed = 40;
   for (speedloop=40; speedloop<=128; speedloop++) {
     motor2speed++;
     ps2x.read_gamepad(false, motor2speed);
     Serial.println(motor2speed);
     delay(50);
   }

   delay(2000);
}
